@@ -38,12 +38,12 @@ using namespace Opcode;
 #define SET_CONTACT(prim_index, flag)		\
 	/* Set contact status */				\
 	mFlags |= flag;							\
-	mTouchedPrimitives->Add(prim_index);
+	mTouchedPrimitives->Add(udword(prim_index));
 
 //! Planes-triangle test
 #define PLANES_PRIM(prim_index, flag)		\
 	/* Request vertices from the app */		\
-	mIMesh->GetTriangle(mVP, prim_index);	\
+	mIMesh->GetTriangle(mVP, prim_index, mVC);	\
 	/* Perform triangle-box overlap test */	\
 	if(PlanesTriOverlap(clip_mask))			\
 	{										\
@@ -56,8 +56,8 @@ using namespace Opcode;
  */
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 PlanesCollider::PlanesCollider() :
-	mPlanes		(null),
-	mNbPlanes	(0)
+	mNbPlanes	(0),
+	mPlanes		(null)
 {
 }
 
