@@ -45,7 +45,9 @@ int dCollideRTL(dxGeom* g1, dxGeom* RayGeom, int Flags, dContactGeom* Contacts,
 	const dVector3& TLPosition = *(const dVector3*)dGeomGetPosition(TriMesh);
 	const dMatrix3& TLRotation = *(const dMatrix3*)dGeomGetRotation(TriMesh);
 
-	TrimeshCollidersCache *pccColliderCache = GetTrimeshCollidersCache();
+	const unsigned uiTLSKind = TriMesh->getParentSpaceTLSKind();
+	dIASSERT(uiTLSKind == RayGeom->getParentSpaceTLSKind()); // The colliding spaces must use matching cleanup method
+	TrimeshCollidersCache *pccColliderCache = GetTrimeshCollidersCache(uiTLSKind);
 	RayCollider& Collider = pccColliderCache->_RayCollider;
 
 	dReal Length = dGeomRayGetLength(RayGeom);
