@@ -34,7 +34,7 @@
 #include "config.h"
 
 // New Implementation
-#if dTRIMESH_OPCODE_USE_NEW_TRIMESH_TRIMESH_COLLIDER
+#if !dTRIMESH_OPCODE_USE_OLD_TRIMESH_TRIMESH_COLLIDER
 
 #if dTRIMESH_ENABLED
 
@@ -492,7 +492,9 @@ dCollideTTL(dxGeom* g1, dxGeom* g2, int Flags, dContactGeom* Contacts, int Strid
     // TLRotation2 = column-major order
     const dMatrix3& TLRotation2 = *(const dMatrix3*) dGeomGetRotation(TriMesh2);
 
-	TrimeshCollidersCache *pccColliderCache = GetTrimeshCollidersCache();
+	const unsigned uiTLSKind = TriMesh1->getParentSpaceTLSKind();
+	dIASSERT(uiTLSKind == TriMesh2->getParentSpaceTLSKind()); // The colliding spaces must use matching cleanup method
+	TrimeshCollidersCache *pccColliderCache = GetTrimeshCollidersCache(uiTLSKind);
     AABBTreeCollider& Collider = pccColliderCache->_AABBTreeCollider;
 	BVTCache &ColCache = pccColliderCache->ColCache;
 	CONTACT_KEY_HASH_TABLE &hashcontactset = pccColliderCache->_hashcontactset;
@@ -1303,5 +1305,5 @@ bool TriTriContacts(const dVector3 tr1[3],
 }
 
 #endif // dTRIMESH_OPCODE
-#endif // dTRIMESH_USE_NEW_TRIMESH_TRIMESH_COLLIDER
+#endif // !dTRIMESH_USE_OLD_TRIMESH_TRIMESH_COLLIDER
 #endif // dTRIMESH_ENABLED
