@@ -2064,7 +2064,7 @@ REGISTER_EXTENSION( ODE_EXT_trimesh )
 		REGISTER_EXTENSION( ODE_OPC_16bit_indices )
 		#endif
 
-		#if dTRIMESH_OPCODE_USE_NEW_TRIMESH_TRIMESH_COLLIDER
+		#if !dTRIMESH_OPCODE_USE_OLD_TRIMESH_TRIMESH_COLLIDER
 		REGISTER_EXTENSION( ODE_OPC_new_collider )
 		#endif
 
